package org.ssssssss.magicboot.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.client.RestClientException;
import org.springframework.web.client.RestTemplate;
import org.ssssssss.magicboot.constant.ERPURLConstant;
import org.ssssssss.magicboot.constant.URLConstant;
import org.ssssssss.magicboot.entity.Filter;
import org.ssssssss.magicboot.utils.CrmRequestUtil;
import org.ssssssss.magicboot.utils.KingDeeUtils;

import java.util.*;

/**
 * 预签合同
 *
 * @param
 * @return null
 * @Author weiloong_zhang
 */
@RestController
@RequestMapping("/api/pre/contract")
@Slf4j
public class PreContractController {

    private RestTemplate restTemplate = new RestTemplate();

    public static void main(String[] args) {
        new PreContractController().syncContract();
        //new PreContractController().bgPreContract();
    }


    /**
     * 智洋同步预签合同
     *
     * @return void
     * @Author weiloong_zhang
     */
    @PostMapping("/sync_pre_contract")
    public void syncContract() {
        CrmRequestUtil crmRequestUtil = new CrmRequestUtil();

        String[] syncStatus = {"option_pending_sync__c", "option_resync__c"};

        JSONObject preContractReq = crmRequestUtil.getCRMList(Arrays.asList(
                //new Filter("IS", "erp_id__c", Arrays.asList("")),
                new Filter("IN", "sync_status__c", Arrays.asList(syncStatus)),
                new Filter("GT", "create_time", Arrays.asList("1748923200000")),
                //new Filter("EQ", "name", Arrays.asList("YQ2505220005")),
                new Filter("EQ", "life_status", Arrays.asList("normal"))
        ), "pre_signed_contract__c");

        JSONObject preContractRes = new JSONObject();

        try {
            preContractRes = restTemplate.postForObject(URLConstant.GET_CUSTOMIZE_LIST_URL, preContractReq, JSONObject.class);
        } catch (RestClientException e) {
            e.printStackTrace();
        }

        System.out.println("查询结果为：" + preContractRes);

        //判断查询是否成功
        if (!"success".equals(preContractRes.getString("errorDescription")) || preContractRes.getJSONObject("data").getJSONArray("dataList").isEmpty()) {
            log.info("查询失败或者没有符合条件的单据");
            return;
        }

        //数据存在
        for (Object preContractObj : preContractRes.getJSONObject("data").getJSONArray("dataList")) {
            JSONObject preContractData = JSON.parseObject(JSON.toJSONString(preContractObj));

            System.out.println("当前正在处理的数据为：" + preContractData);

            String preContractId = preContractData.getString("_id");
            //String createTime = preContractData.getString("create_time");
            String createTime = preContractData.getString("last_modified_time");

            //根据唯一id和创建时间查询是否已经执行当前数据
            JSONObject preContractIsExist = new JSONObject();

            try {
                preContractIsExist = restTemplate.getForObject("http://localhost:18088/Log/query/log_data?table=send_log_htxx&log_type=YQHT&dataId=" + preContractId + "&mark=" + createTime, JSONObject.class);
            } catch (RestClientException e) {
                e.printStackTrace();
            }

            System.out.println(preContractIsExist);

            if (!preContractIsExist.getJSONArray("data").isEmpty()) {
                log.info("当前数据已经执行过了，将不再向下执行");
                continue;
            }

            log.info("没有集成过，将继续向下执行");

            long documentDate = preContractData.getLong("document_date__c");

            Date date = new Date(documentDate);

            //开始封装传输至ERP的请求
            Map erpContractReq = new HashMap<>();
            erpContractReq.put("billno", preContractData.getString("name"));//预签合同编号
            erpContractReq.put("crmid", preContractData.getString("_id"));//CRM唯一性编码
            //erpContractReq.put("project_number", preContractData.getString("opportunity_id__c"));//项目号
            erpContractReq.put("project_number", "SJ20250424-0033");//项目号
            erpContractReq.put("billtype_number", "conm_salcontract_BT_YQ");//单据类型
            erpContractReq.put("billname", preContractData.getString("project_name__c") != null ? preContractData.getString("project_name__c") : "预签合同");//合同名称
            erpContractReq.put("type_number", "XSHT-YQ01");//合同类型
            erpContractReq.put("contparties_number", preContractData.getString("our_company_name__c") != null ? preContractData.getString("our_company_name__c") : "");//合同主体
            erpContractReq.put("createorg_number", preContractData.getString("our_company_name__c") != null ? preContractData.getString("our_company_name__c") : "");//销售组织编码
            erpContractReq.put("org_number", preContractData.getString("our_company_name__c") != null ? preContractData.getString("our_company_name__c") : "");//销售组织编码
            erpContractReq.put("currency_number", "CNY");//本位币.货币代码
            erpContractReq.put("settlecurrency_number", "CNY");//结算币别.货币代码
            erpContractReq.put("biztime", date);//签订日期,单据日期
            erpContractReq.put("biztimebegin", date);//起始日期
            erpContractReq.put("biztimeend", date);//截止日期
            erpContractReq.put("party1st", preContractData.getString("contract_unit_name__c__r"));//甲方
            erpContractReq.put("party2nd", preContractData.getString("our_company_name__c"));//乙方
            erpContractReq.put("bizmode", "C");//业务模式 A:统谈统签, B:统谈分签,C:分谈分签
            erpContractReq.put("isentrysumamt", false);//isentrysumamt

            //部门编码
            String deptCode = "";

            List deptIdList = preContractData.getJSONArray("data_own_department");

            //开始查询部门编码
            JSONObject deptReq = crmRequestUtil.getCRMList(Arrays.asList(
                    new Filter("EQ", "_id", deptIdList)
            ), "DepartmentObj");

            JSONObject deptRes = new JSONObject();

            try {
                deptRes = restTemplate.postForObject(URLConstant.GET_CRM_LIST_URL, deptReq, JSONObject.class);
            } catch (RestClientException e) {
                e.printStackTrace();
            }

            if ("success".equals(deptRes.getString("errorDescription")) && !deptRes.getJSONObject("data").getJSONArray("dataList").isEmpty()) {
                JSONObject deptData = deptRes.getJSONObject("data").getJSONArray("dataList").getJSONObject(0);
                deptCode = deptData.getString("field_Vj6sf__c") != null ? deptData.getString("field_Vj6sf__c") : "";
            }

            //erpContractReq.put("dept", "ZHY");//归属部门
            erpContractReq.put("dept", deptCode);//归属部门
            //erpContractReq.put("dept_number", "004");//归属部门
            erpContractReq.put("dept_number", deptCode);//归属部门

            //获取负责人编码
            String ownerCode = "";

            List ownerIdList = preContractData.getJSONArray("owner");

            JSONObject ownerReq = crmRequestUtil.getCRMList(Arrays.asList(
                    new Filter("EQ", "user_id", ownerIdList)
            ), "PersonnelObj");

            JSONObject ownerRes = new JSONObject();

            try {
                ownerRes = restTemplate.postForObject(URLConstant.GET_CRM_LIST_URL, ownerReq, JSONObject.class);
            } catch (RestClientException e) {
                e.printStackTrace();
            }

            if ("success".equals(ownerRes.getString("errorDescription")) && !ownerRes.getJSONObject("data").getJSONArray("dataList").isEmpty()) {
                JSONObject ownerData = ownerRes.getJSONObject("data").getJSONArray("dataList").getJSONObject(0);
                ownerCode = ownerData.getString("field_T1xid__c") != null ? ownerData.getString("field_T1xid__c") : "";
            }

            //erpContractReq.put("operator", "ID-000016");//todo 负责人
            erpContractReq.put("operator", ownerCode);//负责人

            //合同单位
            String customerId = preContractData.getString("contract_unit_name__c");

            //根据客户唯一id查询客户名称
            JSONObject customerReq = crmRequestUtil.getCRMList(Arrays.asList(
                    new Filter("EQ", "_id", Arrays.asList(customerId))
            ), "AccountObj");

            JSONObject customerRes = new JSONObject();

            try {
                customerRes = restTemplate.postForObject(URLConstant.GET_CRM_LIST_URL, customerReq, JSONObject.class);
            } catch (RestClientException e) {
                e.printStackTrace();
            }

            if (!"success".equals(customerRes.getString("errorDescription")) || customerRes.getJSONObject("data").getJSONArray("dataList").isEmpty()) {
                log.info("客户名称查询失败或者不存在，直接跳过更新");
                continue;
            }

            JSONObject customerData = customerRes.getJSONObject("data").getJSONArray("dataList").getJSONObject(0);

            erpContractReq.put("customer_number", customerData.getString("account_no"));//合同单位名称
            erpContractReq.put("reccustomer_number", customerData.getString("account_no"));//收获客户单位名称
            //erpContractReq.put("customer_number", "Cus-000007");//todo 合同单位名称
            erpContractReq.put("settlecustomer_number", preContractData.getString("billing_customer_code__c") != null ? preContractData.getString("billing_customer_code__c") : "");//结算客户
            erpContractReq.put("payingcustomer_number", preContractData.getString("payment_customer_code__c") != null ? preContractData.getString("payment_customer_code__c") : "");//付款客户

            //获取产品线

            erpContractReq.put("productline_number", preContractData.getString("product_line__c"));//产品线

            //获取具体安装方式

            erpContractReq.put("installationmethod", preContractData.getString("installation_method__c"));//安装方式

            //行业类型

            erpContractReq.put("industrytype_number", preContractData.getString("industry_type__c"));//行业类型
            erpContractReq.put("province", preContractData.getString("field_t3fgo__c__r"));//省
            erpContractReq.put("city", preContractData.getString("field_ngwth__c__r"));//市
            erpContractReq.put("county", preContractData.getString("field_K5p2C__c__r"));//县
            erpContractReq.put("deviceqty", preContractData.getBigDecimal("device_quantity__c") != null ? preContractData.getBigDecimal("device_quantity__c") : 0);//设备数量
            erpContractReq.put("totalallamount", preContractData.getBigDecimal("pre_signed_amount__c") != null ? preContractData.getBigDecimal("pre_signed_amount__c") : 0);//预签金额
            erpContractReq.put("warranty", preContractData.getBigDecimal("warranty_period_months__c") != null ? preContractData.getBigDecimal("warranty_period_months__c") : 0);//质保期

            Map erpContractData = new HashMap<>();
            erpContractData.put("data", Arrays.asList(erpContractReq));//请求体

            String accessToken = new KDTokenController().getKDAccessTokenTest();

            if (accessToken == null || accessToken.equals("")) {
                log.info("金蝶token为空或不存在");
                return;
            }
            String uuid = UUID.randomUUID().toString().replace("-", "");
            //开始封装请求头
            HttpHeaders headers = new HttpHeaders();
            headers.setContentType(MediaType.APPLICATION_JSON);
            headers.set("accessToken", accessToken);
            headers.set("Idempotency-Key", uuid);

            HttpEntity contractReqEntity = new HttpEntity(erpContractData, headers);

            System.out.println(JSON.parseObject(JSON.toJSONString(contractReqEntity)));

            //开始向金蝶发起请求
            String contractUrl = ERPURLConstant.ERP_URL + "/ierp/kapi/v2/f9w5/conm/conm_salcontract/savecontract";

            JSONObject contractRes = new JSONObject();

            try {
                contractRes = restTemplate.postForObject(contractUrl, contractReqEntity, JSONObject.class);
            } catch (RestClientException e) {
                e.printStackTrace();
            }

            //开始封装回写程序
            Map backReqMap = new HashMap();
            backReqMap.put("_id", preContractId);
            backReqMap.put("dataObjectApiName", "pre_signed_contract__c");

            //开始封装日志
            Map logMap = new HashMap<>();
            logMap.put("log_id", UUID.randomUUID().toString().replace("-", ""));
            logMap.put("log_type", "YQHT");
            logMap.put("syn_type", "0");
            logMap.put("data_name", preContractData.getString("name"));
            logMap.put("data_id", preContractId);
            logMap.put("mark", createTime);
            logMap.put("send_body", JSON.toJSONString(contractReqEntity));
            logMap.put("send_res", JSON.toJSONString(contractRes));
            logMap.put("tableName", "send_log_htxx");

            //判断是否执行成功
            if ("0".equals(contractRes.getString("errorCode"))) {
                //同步成功
                logMap.put("log_status", "0");
                logMap.put("res_body", "同步成功");
                backReqMap.put("erp_id__c", contractRes.getJSONObject("data").getJSONArray("result").getJSONObject(0).getString("id"));
                backReqMap.put("sync_status__c", "option_sync_success__c");
                backReqMap.put("response_info__c", "同步成功");

                //开始审核
                KingDeeUtils kingDeeUtils = new KingDeeUtils();
                kingDeeUtils.audit(contractRes.getJSONObject("data").getJSONArray("result").getJSONObject(0).getString("id"), "conm_salcontract");
            } else {
                //同步失败
                logMap.put("log_status", "1");
                logMap.put("res_body", "同步失败：" + contractRes.getString("message"));
                backReqMap.put("sync_status__c", "option_sync_failure__c");
                backReqMap.put("response_info__c", contractRes.getString("message"));
            }

            //开始回写
            JSONObject backReq = crmRequestUtil.updateCRM(backReqMap);

            JSONObject backRes = new JSONObject();

            try {
                backRes = restTemplate.postForObject(URLConstant.UPDATE_CRM_CUSTOMIZE, backReq, JSONObject.class);
            } catch (RestClientException e) {
                e.printStackTrace();
            }

            System.out.println("回写结果为：" + backRes);

            //开始记录日志
            JSONObject logRes = new JSONObject();
            try {
                logRes = restTemplate.postForObject("http://localhost:18088/Log/insert/log_data", logMap, JSONObject.class);
            } catch (RestClientException e) {
                e.printStackTrace();
            }

            System.out.println("日志插入结果为：" + logRes);

        }
    }

    /**
     * 预签合同变更
     *
     * @return void
     * @Author weiloong_zhang
     */
    @PostMapping("/bg_pre_contract")
    public void bgPreContract() {
        CrmRequestUtil crmRequestUtil = new CrmRequestUtil();

        JSONObject preContractBGReq = crmRequestUtil.getCRMList(Arrays.asList(
                new Filter("EQ", "name", Arrays.asList("YQHTBG20250518-0002"))
        ), "pre_signed_contract_amendm__c");

        JSONObject preContractBGRes = new JSONObject();

        try {
            preContractBGRes = restTemplate.postForObject(URLConstant.GET_CUSTOMIZE_LIST_URL, preContractBGReq, JSONObject.class);
        } catch (RestClientException e) {
            e.printStackTrace();
        }

        System.out.println("预签合同变更查询结果为：" + preContractBGRes);

        if (!"success".equals(preContractBGRes.getString("errorDescription")) || preContractBGRes.getJSONObject("data").getJSONArray("dataList").isEmpty()) {
            log.info("不存在要变更的预签合同");
            return;
        }

        for (Object preContractBGObj : preContractBGRes.getJSONObject("data").getJSONArray("dataList")) {
            JSONObject preContractBGData = JSON.parseObject(JSON.toJSONString(preContractBGObj));

            System.out.println("当前正在处理的单据为：" + preContractBGData);

            //开始截取关键数据
            //唯一ID
            String preContractId = preContractBGData.getString("_id");
            //单据名称
            String preContractName = preContractBGData.getString("name");
            //创建时间
            String createTime = preContractBGData.getString("create_time");

            //开始查询是否已经集成过该单据
            JSONObject isLogRes = new JSONObject();

            try {
                isLogRes = restTemplate.getForObject("http://localhost:18088/Log/query/log_data?table=send_log_htxx&log_type=YQHTBG&dataId=" + preContractId + "&mark=" + createTime, JSONObject.class);
            } catch (RestClientException e) {
                e.printStackTrace();
            }

            if (!isLogRes.getJSONArray("data").isEmpty()) {
                log.info("当前数据已经执行过了，将不再向下执行");
                continue;
            }

            log.info("日志不存在，将继续向下执行");

            //开始封装数据
            Map preContractBGMap = new HashMap<>();
            //开始封装传输至ERP的请求
            //preContractBGMap.put("billno", preContractBGData.getString("source_pre_signed_contract__c__r"));//原预签合同编号
            preContractBGMap.put("crmid", preContractBGData.getString("source_pre_signed_contract__c"));//CRM唯一性编码

            //开始查询项目号
            String projectCode = "";

            if (preContractBGData.getString("business_opportunity__c") != null) {
                projectCode = preContractBGData.getString("business_opportunity__c");
            }

            JSONObject projectReq = crmRequestUtil.getCRMList(Arrays.asList(
                    new Filter("EQ", "_id", Arrays.asList(projectCode))
            ), "NewOpportunityObj");

            JSONObject projectRes = new JSONObject();

            try {
                projectRes = restTemplate.postForObject(URLConstant.GET_CUSTOMIZE_LIST_URL, projectReq, JSONObject.class);
            } catch (RestClientException e) {
                e.printStackTrace();
            }

            System.out.println("项目号查询结果为：" + projectRes);

            if (!"success".equals(projectRes.getString("errorDescription")) || projectRes.getJSONObject("data").getJSONArray("dataList").isEmpty()) {
                log.info("商机不存在，将不再向下执行");
                continue;
            }
            projectCode = projectRes.getJSONObject("data").getJSONArray("dataList").getJSONObject(0).getString("opportunity_id__c");

            //preContractBGMap.put("project_number", projectCode);//项目号
            preContractBGMap.put("project_number", "SJ20250424-0033");//项目号
            preContractBGMap.put("billtype_number", "conm_salcontract_BT_YQ");//单据类型
            preContractBGMap.put("billname", preContractBGData.getString("contract_name__c") != null ? preContractBGData.getString("contract_name__c") : "测试");//todo 合同名称
            preContractBGMap.put("type_number", "XSHT-YQ01");//合同类型
            preContractBGMap.put("contparties_number", "BU-0002");//合同主体
            preContractBGMap.put("createorg_number", "zyierp");//销售组织编码
            preContractBGMap.put("org_number", "zyierp");//销售组织编码
            preContractBGMap.put("currency_number", "CNY");//本位币.货币代码
            preContractBGMap.put("settlecurrency_number", "CNY");//结算币别.货币代码

            //日期格式化为Date
            long documentDate = preContractBGData.getLong("document_date__c");
            preContractBGMap.put("biztime", new Date(documentDate));//签订日期,单据日期
            preContractBGMap.put("biztimebegin", new Date(documentDate));//起始日期
            preContractBGMap.put("biztimeend", new Date(documentDate));//截止日期
            preContractBGMap.put("party1st", preContractBGData.getString("contract_unit_name__c__r"));//甲方
            preContractBGMap.put("party2nd", preContractBGData.getString("our_company_name__c"));//乙方
            preContractBGMap.put("bizmode", "C");//业务模式 A:统谈统签, B:统谈分签,C:分谈分签

            //部门编码
            String deptCode = "";

            List deptIdList = preContractBGData.getJSONArray("data_own_department");

            //开始查询部门编码
            JSONObject deptReq = crmRequestUtil.getCRMList(Arrays.asList(
                    new Filter("EQ", "_id", deptIdList)
            ), "DepartmentObj");

            JSONObject deptRes = new JSONObject();

            try {
                deptRes = restTemplate.postForObject(URLConstant.GET_CRM_LIST_URL, deptReq, JSONObject.class);
            } catch (RestClientException e) {
                e.printStackTrace();
            }

            if ("success".equals(deptRes.getString("errorDescription")) && !deptRes.getJSONObject("data").getJSONArray("dataList").isEmpty()) {
                JSONObject deptData = deptRes.getJSONObject("data").getJSONArray("dataList").getJSONObject(0);
                deptCode = deptData.getString("field_Vj6sf__c") != null ? deptData.getString("field_Vj6sf__c") : "";
            }

            preContractBGMap.put("dept", deptCode);//归属部门
            preContractBGMap.put("dept_number", "004");//归属部门

            //获取负责人编码
            String ownerCode = "";

            List ownerIdList = preContractBGData.getJSONArray("owner");

            JSONObject ownerReq = crmRequestUtil.getCRMList(Arrays.asList(
                    new Filter("EQ", "user_id", ownerIdList)
            ), "PersonnelObj");

            JSONObject ownerRes = new JSONObject();

            try {
                ownerRes = restTemplate.postForObject(URLConstant.GET_CRM_LIST_URL, ownerReq, JSONObject.class);
            } catch (RestClientException e) {
                e.printStackTrace();
            }

            if ("success".equals(ownerRes.getString("errorDescription")) && !ownerRes.getJSONObject("data").getJSONArray("dataList").isEmpty()) {
                JSONObject ownerData = ownerRes.getJSONObject("data").getJSONArray("dataList").getJSONObject(0);
                ownerCode = ownerData.getString("field_T1xid__c") != null ? ownerData.getString("field_T1xid__c") : "";
            }

            preContractBGMap.put("operator", "ID-000016");//todo 负责人
            preContractBGMap.put("user_operatornumber", "ID-000016");//todo 负责人

            //合同单位
            String customerId = preContractBGData.getString("contract_unit_name__c");

            //根据客户唯一id查询客户名称
            JSONObject customerReq = crmRequestUtil.getCRMList(Arrays.asList(
                    new Filter("EQ", "_id", Arrays.asList(customerId))
            ), "AccountObj");

            JSONObject customerRes = new JSONObject();

            try {
                customerRes = restTemplate.postForObject(URLConstant.GET_CRM_LIST_URL, customerReq, JSONObject.class);
            } catch (RestClientException e) {
                e.printStackTrace();
            }

            if (!"success".equals(customerRes.getString("errorDescription")) || customerRes.getJSONObject("data").getJSONArray("dataList").isEmpty()) {
                log.info("客户名称查询失败或者不存在，直接跳过更新");
                continue;
            }

            JSONObject customerData = customerRes.getJSONObject("data").getJSONArray("dataList").getJSONObject(0);

            //preContractBGMap.put("customer_number", customerData.getString("account_no"));//合同单位名称
            preContractBGMap.put("customer_number", "Cus-000007");//todo 合同单位名称

            //获取产品线

            preContractBGMap.put("productline_number", preContractBGData.getString("product_line__c"));//产品线

            //获取具体安装方式

            preContractBGMap.put("installationmethod", preContractBGData.getString("installation_method__c"));//安装方式

            //行业类型
            preContractBGMap.put("industrytype_number", preContractBGData.getString("industry_type__c"));//行业类型
            preContractBGMap.put("deviceqty", preContractBGData.getBigDecimal("device_quantity__c") != null ? preContractBGData.getBigDecimal("device_quantity__c") : 0);//设备数量
            preContractBGMap.put("totalallamount", preContractBGData.getBigDecimal("pre_signed_amount__c") != null ? preContractBGData.getBigDecimal("pre_signed_amount__c") : 0);//预签金额
            preContractBGMap.put("warranty", preContractBGData.getBigDecimal("warranty_period_months__c") != null ? preContractBGData.getBigDecimal("warranty_period_months__c") : 0);//质保期

            Map erpContractBGDataReq = new HashMap<>();
            erpContractBGDataReq.put("data", Arrays.asList(preContractBGMap));//请求体

            String accessToken = new KDTokenController().getKDAccessTokenTest();

            if (accessToken == null || accessToken.equals("")) {
                log.info("金蝶token为空或不存在");
                return;
            }
            String uuid = UUID.randomUUID().toString().replace("-", "");
            //开始封装请求头
            HttpHeaders headers = new HttpHeaders();
            headers.setContentType(MediaType.APPLICATION_JSON);
            headers.set("accessToken", accessToken);
            headers.set("Idempotency-Key", uuid);

            HttpEntity contractReqEntity = new HttpEntity(erpContractBGDataReq, headers);

            System.out.println(JSON.parseObject(JSON.toJSONString(contractReqEntity)));

            //开始向金蝶发起请求
            String contractUrl = ERPURLConstant.ERP_URL + "/ierp/kapi/v2/f9w5/conm/salcontract/change";

            String erpPreContractBGRes = "";

            try {
                erpPreContractBGRes = restTemplate.postForObject(contractUrl, contractReqEntity, String.class);
            } catch (RestClientException e) {
                e.printStackTrace();
            }

            JSONObject erpPreContractBGResJson = JSON.parseObject(erpPreContractBGRes);

            System.out.println("金蝶预签结果为：" + erpPreContractBGResJson);

            //开始封装回写程序
            Map backReqMap = new HashMap();
            backReqMap.put("_id", preContractId);
            backReqMap.put("dataObjectApiName", "pre_signed_contract_amendm__c");

            //开始封装日志
            Map logMap = new HashMap<>();
            logMap.put("log_id", UUID.randomUUID().toString().replace("-", ""));
            logMap.put("log_type", "YQHTBG");
            logMap.put("syn_type", "0");
            logMap.put("data_name", preContractName);
            logMap.put("data_id", preContractId);
            logMap.put("mark", createTime);
            logMap.put("send_body", JSON.toJSONString(contractReqEntity));
            logMap.put("send_res", JSON.toJSONString(erpPreContractBGResJson));
            logMap.put("tableName", "send_log_htxx");

            //判断是否执行成功
            if ("0".equals(erpPreContractBGResJson.getString("errorCode"))) {
                //同步成功
                logMap.put("log_status", "0");
                logMap.put("res_body", "同步成功");
                backReqMap.put("erp_id__c", erpPreContractBGResJson.getJSONObject("data").getJSONArray("result").getJSONObject(0).getString("id"));
                backReqMap.put("sync_status__c", "option_sync_success__c");
                backReqMap.put("response_info__c", "同步成功");

                //审核
                KingDeeUtils kingDeeUtils = new KingDeeUtils();
                kingDeeUtils.audit(erpPreContractBGResJson.getJSONObject("data").getJSONArray("result").getJSONObject(0).getString("id"), "conm_salcontract");
            } else {
                //同步失败
                logMap.put("log_status", "1");
                logMap.put("res_body", "同步失败：" + erpPreContractBGResJson.getString("message"));
                backReqMap.put("sync_status__c", "option_sync_failure__c");
                backReqMap.put("response_info__c", erpPreContractBGResJson.getString("message"));
            }

            //开始回写
            JSONObject backReq = crmRequestUtil.updateCRM(backReqMap);

            JSONObject backRes = new JSONObject();

            try {
                backRes = restTemplate.postForObject(URLConstant.UPDATE_CRM_CUSTOMIZE, backReq, JSONObject.class);
            } catch (RestClientException e) {
                e.printStackTrace();
            }

            System.out.println("回写结果为：" + backRes);

            //开始记录日志
            JSONObject logRes = new JSONObject();
            try {
                logRes = restTemplate.postForObject("http://localhost:18088/Log/insert/log_data", logMap, JSONObject.class);
            } catch (RestClientException e) {
                e.printStackTrace();
            }

            System.out.println("日志插入结果为：" + logRes);
        }
    }
}
